package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/23 8:46
 * @Version:V2.0
 */
@FeignClient(value = "DIL-AMS-API-DEV", url = "${openfeign.AmsFeign.url}")
public interface AmsFeign {

    /**
     * 展示违约规则
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/getBreachList")
    RESTfulResult getBreachList(@RequestBody(required = false) Map<String, Object> mapValue,
                                @RequestParam("pageNum") Integer pageNum,
                                @RequestParam("pageSize") Integer pageSize,
                                @RequestParam("apiId") Integer apiId);

    /**
     * 新增违约规则
     *
     * @param amsContractBreach
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/addContractBreach")
    RESTfulResult addContractBreach(@RequestBody Map<String, Object> amsContractBreach);

    /**
     * 逻辑删除违约规则
     *
     * @param breachId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/deleteContractBreach/{breachId}")
    RESTfulResult deleteContractBreach(@PathVariable("breachId") BigDecimal breachId);

    /**
     * 通过违约id查询
     *
     * @param breachId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/selectBreachToUpdate/{breachId}")
    RESTfulResult selectBreachToUpdate(@PathVariable("breachId") BigDecimal breachId);

    /**
     * 修改违约规则
     *
     * @param amsContractBreach
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/updateContractBreach")
    RESTfulResult updateContractBreach(@RequestBody Map<String, Object> amsContractBreach);

    /**
     * 展示港口装卸单价列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/getLoadUnloadPriceList")
    RESTfulResult getLoadUnloadPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                         @RequestParam Integer pageNum,
                                         @RequestParam Integer pageSize,
                                         @RequestParam Integer apiId);

    /**
     * 新增港口装卸单价
     *
     * @param amsContractOtherPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/addLoadUnloadPrice")
    RESTfulResult addLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice);

    /**
     * 逻辑删除港口装卸单价
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/deleteLoadUnloadPrice/{priceId}")
    RESTfulResult deleteLoadUnloadPrice(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 通过单价id查询
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/selectLoadUnloadPriceToUpdate/{priceId}")
    RESTfulResult selectLoadUnloadPriceToUpdate(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 修改港口装卸单价
     *
     * @param amsContractOtherPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/updateLoadUnloadPrice")
    RESTfulResult updateLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice);


    /**
     * 展示火运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/getTrainPriceList")
    RESTfulResult getTrainPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam Integer pageNum,
                                    @RequestParam Integer pageSize,
                                    @RequestParam Integer apiId);

    /**
     * 新增火运单价
     *
     * @param amsContractTrainPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/addTrainPrice")
    RESTfulResult addTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice);

    /**
     * 逻辑删除火运单价
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/deleteTrainPrice/{priceId}")
    RESTfulResult deleteTrainPrice(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 通过单价id查询
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/selectTrainPriceToUpdate/{priceId}")
    RESTfulResult selectTrainPriceToUpdate(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 修改火运单价
     *
     * @param amsContractTrainPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/updateTrainPrice")
    RESTfulResult updateTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice);


    /**
     * 展示水运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/getShipPriceList")
    RESTfulResult getShipPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                   @RequestParam Integer pageNum,
                                   @RequestParam Integer pageSize,
                                   @RequestParam Integer apiId);

    /**
     * 新增水运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/addShipPrice")
    RESTfulResult addShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 逻辑删除运费单价
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/deleteShipPrice/{priceId}")
    RESTfulResult deleteShipPrice(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 修改水运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/updateShipPrice")
    RESTfulResult updateShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 通过单价id查询
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/selectPriceToUpdate/{priceId}")
    RESTfulResult selectPriceToUpdate(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 展示汽运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/getTruckPriceList")
    RESTfulResult getTruckPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam Integer pageNum,
                                    @RequestParam Integer pageSize,
                                    @RequestParam Integer apiId);

    /**
     * 新增汽运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/addAmsContractTransportPrice")
    RESTfulResult addAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 修改汽运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/updateAmsContractTransportPrice")
    RESTfulResult updateAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
//     * 油价联动导致运价变动，批量修改运价
//     *
//     * @return
//     */
//    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/batchUpdateTransportPriceByOilPrice")
//    RESTfulResult batchUpdateTransportPriceByOilPrice();

    /**
     * 展示采购订单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amspurchaseorders/getPurchaseOrderList")
    RESTfulResult getPurchaseOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);

    /**
     * 下拉框
     * @return
     */
    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getAddressDeliveryAddress")
    RESTfulResult getAddressDeliveryAddress();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getShipperId")
    RESTfulResult getShipperId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getCarrierId")
    RESTfulResult getCarrierId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getCapacityId")
    RESTfulResult getCapacityId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getMaterialId")
    RESTfulResult getMaterialId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getTruckCapacityId")
    RESTfulResult getTruckCapacityId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getLineId")
    RESTfulResult getLineId();
// ----------------------------------------------销售合同-------------------------------------
    /**
     * 销售合同查询汽运单价
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询汽运单价信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(109)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/saleContract/amscontracttransportprices/getAmsContractTransportPrice")
    RESTfulResult amscontracttransportprices(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);
    /**
     *销售合同新增汽运单价
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/addAmsContractTransportUnitPrice")
    RESTfulResult addAmsContractTransportUnitPrice(@RequestBody(required = false) Map<String, Object> mapVal);

    /**
     *通过主键id删除汽运单价
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/deleteAmsContractTransportPrice")
    RESTfulResult deleteAmsContractTransportPrice(BigDecimal priceId);
    /**
     *通过主键渲染信息
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/getAmsContractTransportPriceByPriceId/{priceId}")
    RESTfulResult getAmsContractTransportPriceByPriceId(@PathVariable("priceId") BigDecimal priceId);
    /**
     * 通过主键修改汽运单价
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/updateAmsContractTransportUnitPrice")
    RESTfulResult updateAmsContractTransportUnitPrice(@RequestBody(required = false) Map<String, Object> mapVal);
    /**
     * 油价联动导致运价变动，批量修改运价
     * @param
     * @return
     */
    @ApiOperation(value="油价联动导致运价变动，批量修改运价")
    @ApiImplicitParams({
    })
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/batchUpdateTransportPriceByOilPrice")
    RESTfulResult batchUpdateTransportPriceByOilPrice(@RequestBody(required = false) Map<String, Object> mapVal);
    /**
     * 获取线路编号
     * @param
     * @return
     */
    @ApiOperation(value="获取线路编号")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getLineNo")
    RESTfulResult getLineNo();
    /**
     * 获取线路编号
     * @param
     * @return
     */
    @ApiOperation(value="获取运力编号")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getCapacityNumber")
    RESTfulResult getCapacityNumber();
    /**
     * 获取收货地址
     * @param
     * @return
     */
    @ApiOperation(value="获取收货地址")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getDeliveryAddress")
    RESTfulResult getDeliveryAddress();
    /**
     * 新增(固定派单/公开抢单)
     * @param mapVal
     * @return
     */
    @ApiOperation(value="新增(固定派单/公开抢单)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsDispatchSaleOrder", value = "(固定派单/公开抢单)对象", required = false, dataType = "AmsDispatchSaleOrder")
    })
    @PostMapping(value = "/api/v1/ams/amsdispatchsaleorders/addAmsDispatchSaleOrder")
    RESTfulResult addAmsDispatchSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal);
    /**
     * 获取收货地址
     * @param
     * @return
     */
    @ApiOperation(value="获取收货地址")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amsdispatchsaleorders/getCarrierName")
    RESTfulResult getCarrierName();

    /**
     * 查询未上报销售订单信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询未上报销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(98)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/api/v1/ams/amssaleorders/getSaleOrderInfo")
    RESTfulResult getSaleOrderInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize,
                                             @RequestParam Integer apiId);
    /**
     * 查询已上报销售订单信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询已上报销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(98)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/api/v1/ams/amssaleorders/getSaleOrderReported")
    RESTfulResult getSaleOrderReported(@RequestBody(required = false) Map<String, Object> mapValue,
                                   @RequestParam Integer pageNum,
                                   @RequestParam Integer pageSize,
                                   @RequestParam Integer apiId);

    /**
     * 查询财务已审批销售订单信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询财务已审批销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(105)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/api/v1/ams/amssaleorders/getAmsSaleOrderApproved")
    RESTfulResult getAmsSaleOrderApproved(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);

    /**
     * 根据销售订单号查询销售订单详细信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */

    @ApiOperation(value="根据销售订单号查询销售订单详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(100)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/api/v1/ams/amssaleorders/getSaleOrderDetail")
    RESTfulResult getSaleOrderDetail(@RequestBody(required = false) Map<String, Object> mapValue,
                                          @RequestParam Integer pageNum,
                                          @RequestParam Integer pageSize,
                                          @RequestParam Integer apiId);
    /**
     * 上传销售订单
     * @param saleOrderId
     * @return
     */
    @ApiOperation(value="上传销售订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderId", value = "销售订单ID", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/uploadSaleOrder/{saleOrderId}")
    RESTfulResult uploadSaleOrder(@PathVariable("saleOrderId") BigDecimal saleOrderId);
    /**
     * 新增销售订单
     */
    @ApiOperation(value="新增销售订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrder", value = "销售订单对象", required = false, dataType = "AmsSaleOrder")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/addAmsSaleOrder")
    RESTfulResult addAmsSaleOrder(@RequestBody(required = false) Map<String,Object> map);

    /**
     * 通过主键渲染销售订单信息
     * @param saleOrderId
     * @return
     */
    @ApiOperation(value="通过主键渲染销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/getAmsSaleOrderBySaleOrderId/{saleOrderId}")
    RESTfulResult getAmsSaleOrderBySaleOrderId(@PathVariable("saleOrderId") BigDecimal saleOrderId);
    /**
     * 通过主键修改销售订单
     * @param map
     * @return
     */
    @ApiOperation(value="通过主键修改销售订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrder", value = "销售订单对象", required = false, dataType = "AmsSaleOrder")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/updateAmsSaleOrder")
    RESTfulResult updateAmsSaleOrder(@RequestBody(required = false) Map<String,Object> map);
    /**
     * 通过主键删除销售订单
     * @param saleOrderId
     * @return
     */
    @ApiOperation(value="通过主键删除销售订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/deleteAmsSaleOrderBySaleOrderId")
    RESTfulResult deleteAmsSaleOrderBySaleOrderId(BigDecimal saleOrderId);
    @ApiOperation(value="根据销售订单号查询销售订单修改日志")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(100)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/getSaleOrderUpdateLog")
    RESTfulResult getSaleOrderUpdateLog(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam Integer pageNum,
                                     @RequestParam Integer pageSize,
                                     @RequestParam Integer apiId);
    /**
     * 获取发货单位
     */
    @ApiOperation(value="获取发货单位")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amssaleorders/getShipperName")
    RESTfulResult getShipperName();
    /**
     * 获取收货单位
     */
    @ApiOperation(value="获取收货单位")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amssaleorders/getConsigneeCompanyName")
    RESTfulResult getConsigneeCompanyName();
    /**
     * 新增销售订单物资信息
     * @param map
     * @return
     */
    @ApiOperation(value="新增销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/addAmsSaleOrderMaterial")
    RESTfulResult addAmsSaleOrderMaterial(@RequestBody(required = false) Map<String,Object> map);

    /**
     *通过主键渲染销售订单物资信息
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键渲染销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/getAmsSaleOrderMaterialBySaleOrderMaterialId/{saleOrderMaterialId}")
    RESTfulResult getAmsSaleOrderMaterialBySaleOrderMaterialId(@PathVariable("saleOrderMaterialId") BigDecimal saleOrderMaterialId);
    /**
     * 通过主键删除销售订单物资信息
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键删除销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/deleteAmsSaleOrderMaterialBySaleOrderMaterialId")
    RESTfulResult deleteAmsSaleOrderMaterialBySaleOrderMaterialId(BigDecimal saleOrderMaterialId);

    /**
     * 通过主键获取收货地址
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键获取收货地址")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/getAddress/{saleOrderMaterialId}")
    RESTfulResult getAddress(BigDecimal saleOrderMaterialId);


    /**
     * 通过主键修改销售订单信息(新增一条），过去的成为历史记录
     * @param map
     * @return
     */
    @ApiOperation(value="通过主键修改销售订单信息(新增一条），过去的成为历史记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/updateAddress")
    RESTfulResult updateAddress(@RequestBody(required = false)Map<String,Object> map);

    /**
     * 查询销售计划信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询销售计划信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(92)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/getSalePlanInfo")
    RESTfulResult getSalePlanInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize,
                                        @RequestParam Integer apiId);

    /**
     * 新增销售计划
     * @param map
     * @return
     */
    @ApiOperation(value="新增销售计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amssaleplans", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/addAmsSalePlan")
    RESTfulResult addAmsSalePlan(@RequestBody(required = false)Map<String,Object> map);

    /**
     * 通过主键查询销售计划信息
     * @param planId
     * @return
     */
    @ApiOperation(value="通过主键查询销售计划信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "销售计划主键", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/getAmsSalePlanByPlanId/{planId}")
    RESTfulResult getAmsSalePlanByPlanId(@PathVariable("planId") BigDecimal planId);
    /**
     * 通过主键修改销售计划
     * @param map
     * @return
     */
    @ApiOperation(value="通过主键修改车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSalePlan", value = "修改车皮装车map", required = false, dataType = "AmsSalePlan")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/upadteAmsSalePlanByPlanId")
    RESTfulResult upadteAmsSalePlanByPlanId(@RequestBody(required = false)Map<String,Object> map);
    /**
     * 通过主键删除销售计划
     * @param planId
     * @return
     */
    @ApiOperation(value="通过主键删除车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "主键ID", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/deleteAmsSalePlanByPlanId")
    RESTfulResult deleteAmsSalePlanByPlanId(@RequestParam BigDecimal planId);

    /**
     * 获取规格型号
     * @param
     * @return
     */
    @ApiOperation(value="获取规格型号")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amssaleplans/getMaterialName")
    RESTfulResult getMaterialName();

    /**
     * 获取销售片区名称
     * @param
     * @return
     */
    @ApiOperation(value="获取销售片区名称")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amssaleplans/getAreaName")
    RESTfulResult getAreaName();

    /*
       AmstruckPurplanController中所有接口
    */
    @PostMapping("api/v1/ams/amstruckpurplans/getAllPurPlan")
    RESTfulResult getAllPurPlan(@RequestBody(required=false) Map<String,Object> mapValue,
                                @RequestParam("apiId") Integer apiId,
                                @RequestParam("pageNum") Integer pageNum,
                                @RequestParam("pageSize") Integer pageSize,
                                @RequestParam("status") Integer status);

    @PostMapping("api/v1/ams/amstruckpurplans/getAllPurPlan/{apiId}")
    public RESTfulResult getDetailListByCon(@PathVariable("apiId") Integer apiId,
                                            @RequestBody(required=false) Map<String,Object> mapValue,
                                            @RequestParam("pageNum")Integer pageNum,
                                            @RequestParam("pageSize")Integer pageSize,
                                            @RequestParam("con")String con);

    @PostMapping ("api/v1/ams/amstruckpurplans/getPurPlanById/{planId}")
    public RESTfulResult getPurPlanById(@PathVariable("planId")Integer planId);

    @PostMapping("api/v1/ams/amstruckpurplans/addPurPlan")
    public RESTfulResult addPurPlan(@RequestBody Map<String, Object> map);

    @PostMapping("api/v1/ams/amstruckpurplans/sendPurPlan/{planId}")
    public RESTfulResult sendPurPlan(@PathVariable("planId")Integer planId);

    @PostMapping("api/v1/ams/amstruckpurplans/receptionPurPlan/{planId}")
    public RESTfulResult receptionPurPlan(@PathVariable("planId")Integer planId);



    @PostMapping("api/v1/ams/amstruckpurplans/deletePurPlan/{planId}")
    public RESTfulResult deletePurPlan(@PathVariable("planId")Integer planId);

    @PostMapping("api/v1/ams/amstruckpurplans/getDecomposedPlan")
    public RESTfulResult getDecomposedPlan(@RequestBody(required=false) Map<String,Object> mapValue,
                                           @RequestParam("apiId") Integer apiId,
                                           @RequestParam("pageNum") Integer pageNum,
                                           @RequestParam("pageSize") Integer pageSize,
                                           @RequestParam("planId") Integer planId,
                                           @RequestParam("status") Integer status);

    //*****************************************内转物流**************************************
    //查询汽运单价
    @PostMapping(value = "/api/v1/ams/amscontracttransportprices/getAmsContractTransportPriceForConverted")
<<<<<<< HEAD
    Map<String,Object> getAmsContractTransportPriceForConverted(@RequestParam("lineId") BigDecimal lineId,
                                                                @RequestParam("apiId")  Integer apiId,
=======
    Map<String,Object> getAmsContractTransportPriceForConverted(@RequestParam("lineId")BigDecimal lineId,
                                                                @RequestParam("apiId")Integer apiId,
>>>>>>> ab3706e4019b68de223c05db280a865bdd315882
                                                                @RequestParam("pageNum")Integer pageNum,
                                                                @RequestParam("pageSize")Integer pageSize);
    //获得运输线路
    @GetMapping(value = "/api/v1/ams/amscontracttransportprices/getLineRoute")
    Map<String,Object> getLineRoute();




}